pub struct AtlasHandle(/* private fields */);Expand description
Generation-based opaque handle to an atlas allocation.
Handles are invalidated when the atlas is resized or when the corresponding region is evicted via LRU.