push_line_quad

Function push_line_quad 

pub fn push_line_quad(out: &mut Vec<Vertex>, params: LineQuadParams)
Append six vertices for a line-segment SDF quad.

The quad is expanded perpendicular to the line by half_width + 1.0 pixels to ensure the anti-aliased edge is not clipped.

When aa_smooth is true, the shader uses smoothstep for soft edges. When false, the edge is hard-clipped.