Module exec

Module exec 

GPU pass execution helpers and per-frame statistics for WgpuBackend.

This module owns:

  • FrameStats — per-frame draw-call and render-pass counters.
  • run_solid_pass — executes the solid vertex-buffer pass using a persistent, reused, growable vertex buffer.
  • run_gradient_pass_batched — executes ALL gradient draws in a single render pass using dynamic-offset uniforms.
  • run_textured_pass — executes one textured render pass.

Structs

FrameStats
Per-frame draw-call and render-pass counters.