DrawBatch

Struct DrawBatch 

pub struct DrawBatch {
    pub key: BatchKey,
    pub command_range: Range<usize>,
    pub instance_count: usize,
}
A contiguous run of draw commands that share the same BatchKey.

Fields

key: BatchKey

The shared pipeline / texture / blend state.

command_range: Range<usize>

Range of original command indices (before sorting) covered by this batch. The GPU consumer uses these to look up the actual commands.

instance_count: usize

Number of draw instances in this batch.